/*Load data - replace the text "PATH TO FOLDER WITH FILES HERE" with the 
file path to the folder where the analyses files are located*/
*cd "FILE PATH TO FOLDER HERE"
cd "~/Documents/Duke/Values and action paper/Files for Website posting/"
use "decisiondata.dta", clear

/*there are few missing, but impute anyway as a precaution*/
/*NOTE: this uses the chained equations approach which allows you
to set a random number seed - hence the results should exactly duplicate
those in the paper*/
mi set wide
mi register imputed female age city_type numhh ///
	religpref2 income income_others conslib attention_probs_dg ///
	sv1 sv2 sv3 sv4 sv5 sv6 sv7 sv8 sv9 sv10 sv11 sv12 sv13 ///
	sv14 sv15 sv16 sv17 sv18 sv19 sv20 sv21 giveticks 
mi register regular race married educ attend weight highload

/*impute the data a few imputations at a time - I originally imputed in this
way because the algorithm occassionally runs into trouble, so this allowed
me to save my progress after each set of imputations*/
mi impute chained ///
	(regress)   age sv1 sv2 sv3 sv4 sv5 sv6 sv7 sv8 sv9 sv10 sv11 sv12 sv13 ///
		sv14 sv15 sv16 sv17 sv18 sv19 sv20 sv21 income income_others conslib ///
	(logit)   	female attention_probs_dg ///
	(mlogit) 	city_type religpref2 ///
	(poisson) 	numhh ///
	(nbreg) 	giveticks ///
	= i.race i.married i.educ attend i.highload  [pweight=weight], ///
	savetrace("values_and_dual_imps_to_check.dta", replace detail) add(5) burnin(50) ///
	rseed(55678) dots
/*add 5 more imputations*/
timer clear 1
timer on 1
mi impute chained ///
	(regress)   age sv1 sv2 sv3 sv4 sv5 sv6 sv7 sv8 sv9 sv10 sv11 sv12 sv13 ///
		sv14 sv15 sv16 sv17 sv18 sv19 sv20 sv21 income income_others conslib ///
	(logit)   	female attention_probs_dg ///
	(mlogit) 	city_type religpref2 ///
	(poisson) 	numhh ///
	(nbreg) 	giveticks ///
	= i.race i.married i.educ attend i.highload  [pweight=weight], ///
	savetrace("values_and_dual_imps_to_check2.dta", replace detail) add(5) burnin(50) ///
	rseed(77856) dots
timer off 1
timer list 1
/*add 10 more imputations*/
timer clear 1
timer on 1
mi impute chained ///
	(regress)   age sv1 sv2 sv3 sv4 sv5 sv6 sv7 sv8 sv9 sv10 sv11 sv12 sv13 ///
		sv14 sv15 sv16 sv17 sv18 sv19 sv20 sv21 income income_others conslib ///
	(logit)   	female attention_probs_dg ///
	(mlogit) 	city_type religpref2 ///
	(poisson) 	numhh ///
	(nbreg) 	giveticks ///
	= i.race i.married i.educ attend i.highload  [pweight=weight], ///
	savetrace("values_and_dual_imps_to_check3.dta", replace detail) add(10) burnin(50) ///
	rseed(223456) dots
timer off 1
timer list 1


/*save data*/
*save "values and dual processes imputed 2-6-14.dta", replace

/*code value variables*/
mi passive: egen svmean=rowmean(sv1 sv2 sv3 sv4 sv5 sv6 sv7 sv8 sv9 sv10 sv11 sv12 sv13 ///
		sv14 sv15 sv16 sv17 sv18 sv19 sv20 sv21) 
foreach x of varlist sv1 sv2 sv3 sv4 sv5 sv6 sv7 sv8 sv9 sv10 sv11 sv12 sv13 ///
		sv14 sv15 sv16 sv17 sv18 sv19 sv20 sv21 {
		mi passive: gen `x'_miadj=`x'-svmean
	}
/*create self-transcendence and outcome variable*/
/*reporeted alpha for self-transcendence is the average of all 
20 alphas that are printed*/
mi xeq: alpha sv10_miadj sv21_miadj, gen(hedon_mi)
mi xeq: alpha sv12_miadj sv18_miadj sv3_miadj sv8_miadj sv19_miadj sv4_miadj ///
	sv13_miadj sv2_miadj sv17_miadj hedon_mi, item gen(st)	
/*standardize self-transcendence variable*/
mi xeq: center st, s
mi xeq: gen self_trans=c_st
mi xeq: drop c_st
/*outcome variable - tickets given*/
mi passive: gen giveticks_fac=1 if giveticks < 5
mi passive: replace giveticks_fac=2 if giveticks==5
mi passive: replace giveticks_fac=3 if giveticks>5 & !missing(giveticks)
label define tix 1 "< 5" 2 "5" 3 "> 5"
mi xeq: label values giveticks_fac tix

/*estimate the propensity score model*/

/*initial model based on stepAIC procedure in R that checked all 
2 way interactions and squared terms for non-binary variables */
mi estimate, dots: regress self_trans female c.age##c.age i.educ i.city_type i.race numhh ///
	i.religpref2 c.attend##c.attend income income_others conslib ///
	c.attend#c.income_others i.race#c.income_others c.age#i.religpref2 ///
	c.numhh#c.attend c.age#i.city_type c.age#c.numhh c.numhh#c.income
est store m1
mi test c.numhh#c.attend c.age#c.numhh

mi estimate, dots: regress self_trans female c.age##c.age i.educ i.city_type i.race numhh ///
	i.religpref2 c.attend##c.attend income income_others conslib ///
	c.attend#c.income_others i.race#c.income_others c.age#i.religpref2 ///
	c.age#i.city_type c.numhh#c.income
est store m2
mi estimate, coeflegend
mi test 2.city_type#c.age 3.city_type#c.age 4.city_type#c.age ///
	5.city_type#c.age
mi test 2.city_type#c.age 3.city_type#c.age 4.city_type#c.age ///
	5.city_type#c.age 2.city_type 3.city_type 4.city_type 5.city_type
mi test c.age#c.age c.attend#c.income_others

mi estimate, dots: regress self_trans female age i.educ i.city_type i.race numhh ///
	i.religpref2 c.attend##c.attend income income_others conslib ///
	i.race#c.income_others c.age#i.religpref2 ///
	c.age#i.city_type c.numhh#c.income
est store m3
mi test 2.city_type#c.age 3.city_type#c.age 4.city_type#c.age ///
	5.city_type#c.age
mi test 2.city_type#c.age 3.city_type#c.age 4.city_type#c.age ///
	5.city_type#c.age 2.city_type 3.city_type 4.city_type 5.city_type
mi test 2.educ 3.educ 4.educ 5.educ

mi estimate, dots: regress self_trans female age i.city_type i.race numhh ///
	i.religpref2 c.attend##c.attend income income_others conslib ///
	i.race#c.income_others c.age#i.religpref2 ///
	c.age#i.city_type c.numhh#c.income
est store m4
mi test 2.city_type#c.age 3.city_type#c.age 4.city_type#c.age ///
	5.city_type#c.age
mi test 2.city_type#c.age 3.city_type#c.age 4.city_type#c.age ///
	5.city_type#c.age 2.city_type 3.city_type 4.city_type 5.city_type
mi test 2.race#c.income_others 3.race#c.income_others 4.race#c.income_others ///
	5.race#c.income_others
mi test 2.religpref2#c.age 3.religpref2#c.age 4.religpref2#c.age
mi test 2.city_type 3.city_type 4.city_type 5.city_type
mi test 2.race 3.race 4.race 5.race
mi test 2.religpref2 3.religpref2 4.religpref2

/*use m4 as the pscore model - Online Supplement Table D3*/
/*f-tests given above in the final set of "mi test" statements*/
mi estimate, dots saving("MI pscore model.ster", replace): ///
	regress self_trans female age i.city_type i.race numhh ///
	i.religpref2 c.attend##c.attend income income_others conslib ///
	i.race#c.income_others c.age#i.religpref2 ///
	c.age#i.city_type c.numhh#c.income

/*calculate propensity scores*/
mi predict st_pred using "MI pscore model.ster"

/*breakpoints for dividing respondents into strata*/
egen breaks_selftrans60 = cut(st_pred), group(60)
egen breaks_selftrans70 = cut(st_pred), group(70)
egen breaks_selftrans80 = cut(st_pred), group(80)
egen breaks_selftrans90 = cut(st_pred), group(90)
egen breaks_selftrans100 = cut(st_pred), group(100)
egen breaks_selftrans120 = cut(st_pred), group(120)

/*create deviation scores*/
mi passive: by breaks_selftrans60: egen st_strata_mean60 = mean(self_trans)
mi passive: gen self_trans_dev60 = self_trans - st_strata_mean60
mi passive: by breaks_selftrans70: egen st_strata_mean70 = mean(self_trans)
mi passive: gen self_trans_dev70 = self_trans - st_strata_mean70
mi passive: by breaks_selftrans80: egen st_strata_mean80 = mean(self_trans)
mi passive: gen self_trans_dev80 = self_trans - st_strata_mean80
mi passive: by breaks_selftrans90: egen st_strata_mean90 = mean(self_trans)
mi passive: gen self_trans_dev90 = self_trans - st_strata_mean90
mi passive: by breaks_selftrans100: egen st_strata_mean100 = mean(self_trans)
mi passive: gen self_trans_dev100 = self_trans - st_strata_mean100
mi passive: by breaks_selftrans120: egen st_strata_mean120 = mean(self_trans)
mi passive: gen self_trans_dev120 = self_trans - st_strata_mean120

/*show variation in self-trans within each stratum*/
bys breaks_selftrans80: su self_trans

/*at this point, the MI data reduces to the unimputed complete case data
because the variables used in analyses (after removal of those who
did not pay attention) have no missing*/
su self_trans_dev80 highload giveticks_fac if attention_probs_dg==0
/*the advantage to using MI previously is the ability to get a propensity
score for the few cases that would be eliminated from your pscore model due
to missingness*/

/*get estimation sample*/
drop if missing(attention_probs_dg) | missing(giveticks)
mi update

/*ADD descriptives */
mi estimate: mean self_trans highload age conslib female income income_others ///
	numhh attend married if attention_probs_dg==0
/*to obtain SD for non-dictomous variables multiply the SE by sqrt(907)*/	
mi estimate: proportion city_type religpref2 race educ if attention_probs_dg==0


/*analyses*/
mlogit giveticks_fac self_trans_dev80 i.highload if attention_probs_dg==0, base(1)  
est store mlogit1

mlogit giveticks_fac self_trans_dev80 i.highload if attention_probs_dg==0 ///
	[pweight=weight], base(1)  
est store mlogit1_wgt

mlogit giveticks_fac self_trans_dev80 i.highload c.self_trans_dev80#i.highload ///
	if attention_probs_dg==0, base(1)  
est store mlogit2
/*marginal effects of self-transcendence in high load condition*/
margins i.highload, dydx(self_trans_dev80) predict(xb outcome(2))
margins i.highload, dydx(self_trans_dev80) predict(xb outcome(3))

mlogit giveticks_fac self_trans_dev80 i.highload c.self_trans_dev80#i.highload ///
	if attention_probs_dg==0 [pweight=weight], base(1)  
est store mlogit2_wgt
/*marginal effects of self-transcendence in high load condition*/
margins i.highload, dydx(self_trans_dev80) predict(xb outcome(2))
margins i.highload, dydx(self_trans_dev80) predict(xb outcome(3))

/*Table 2*/
estout mlogit1 mlogit1_wgt mlogit2 mlogit2_wgt, cell(b se) 
estout mlogit1 mlogit1_wgt mlogit2 mlogit2_wgt, cell(b(star)) 

/*some predicted values for a sense of the magnitude of the effect - 
Figure 7*/
est restore mlogit2
margins i.highload, predict(pr outcome(1)) at(self_trans_dev80=(-1 1))
margins i.highload, predict(pr outcome(2)) at(self_trans_dev80=(-1 1))
margins i.highload, predict(pr outcome(3)) at(self_trans_dev80=(-1 1))

/*when you plot these bargraphs, use 1.39*SE for CI bars, 
calculated following the method in Goldstein and Healy 1995 - you can
use the R code below. Note that these CI's allow you to compare predictions
to one another, but they cannot be used to compare predictions
to 0 - for that you want 2*SE

#figure out the appropriate z value for comparisons between all the means, which will depend on their SE's
#scan in all SE's from predictions from spreadsheet
sigma=scan()
#this function gets the SE ratio - see equation 2 in Goldstein and Healy 1995 
adj.comp=function(x){
	return((x[1]+x[2])/sqrt(x[1]^2 + x[2]^2))
}
#get ratios for all two-way combinations
adj=combn(sigma, 2, adj.comp)

#go with the highest ratio so that you are being conservative for all orthodox/progressivist comparisons
ratio=max(adj)
z=seq(from=1, to=2, by=.001)

findZ=function(z.vec){
	prob.level=c()
	for(i in 1:length(z.vec)){
		prob.level=c(prob.level, 2*(1-pnorm(z.vec[i]*ratio)))
	}
	return(prob.level)
}

pvals=findZ(z)
ind=which(abs(.05-pvals)==min(abs(.05-pvals)))
z[ind]
#this is the confidence interval to ask for, i.e. a 68%, a 95%, etc.
1-2*(1-pnorm(z[ind]))
*/

/*** Sensitivity Checks ***/

/*sensitivity check - how different are results if you leave in those
people who may not have been paying attention to the high load manipulation?*/
/*stronger results without the non-attention folks, but same general pattern*/
mlogit giveticks_fac self_trans_dev80 i.highload c.self_trans_dev80#i.highload, base(1)  
est store mlogit2c

estout mlogit2 mlogit2c

/*how sensitive are the results to changing the number of cases in each stratum?*/
mlogit giveticks_fac self_trans i.highload c.self_trans#i.highload ///
	if attention_probs_dg==0, base(1)  
est store mlogit2_1
mlogit giveticks_fac self_trans_dev60 i.highload c.self_trans_dev60#i.highload ///
	if attention_probs_dg==0, base(1)  
est store mlogit2_60
mlogit giveticks_fac self_trans_dev100 i.highload c.self_trans_dev100#i.highload ///
	if attention_probs_dg==0, base(1)  
est store mlogit2_100
mlogit giveticks_fac self_trans_dev120 i.highload c.self_trans_dev120#i.highload ///
	if attention_probs_dg==0, base(1)  
est store mlogit2_120

estout mlogit2_1 mlogit2_60 mlogit2 mlogit2_100 mlogit2_120, cell(b) 
/*how sensitive are the effects in the highload condition?*/
est restore mlogit2_1
margins i.highload, dydx(self_trans) predict(xb outcome(2))
margins i.highload, dydx(self_trans) predict(xb outcome(3)) 
est restore mlogit2_60
margins i.highload, dydx(self_trans_dev60) predict(xb outcome(2))
margins i.highload, dydx(self_trans_dev60) predict(xb outcome(3))
est restore mlogit2_100
margins i.highload, dydx(self_trans_dev100) predict(xb outcome(2))
margins i.highload, dydx(self_trans_dev100) predict(xb outcome(3))
est restore mlogit2_120
margins i.highload, dydx(self_trans_dev120) predict(xb outcome(2))
margins i.highload, dydx(self_trans_dev120) predict(xb outcome(3))


/*sensitivity check (not in paper) - since the effect sizes are similar between the 
pscore and the normal models, how do the magnitudes of the control variables
compare to those of self-transcendence? */
/*just use main effects of controls for simplicity in presentation*/
/*lose a few people by not using MI data, like 4*/
tab highload attention_probs_dg
mlogit giveticks_fac c.self_trans##i.highload i.female age i.educ ///
	i.city_type i.race numhh ///
	i.religpref2 attend income income_others conslib ///
	if attention_probs_dg==0 & highload==1, base(1)  
est store mlogit1c

/*compare to social categories*/
/*the average marginal effect*/
margins educ, predict(pr outcome(1)) 
margins educ, predict(pr outcome(2))
margins educ, predict(pr outcome(3))
margins race, predict(pr outcome(1))
margins race, predict(pr outcome(2))
margins race, predict(pr outcome(3))
*from 1-20k to 60-80k
margins, predict(pr outcome(1)) at(income=(1 4))
margins, predict(pr outcome(2)) at(income=(1 4))
margins, predict(pr outcome(3)) at(income=(1 4))
*never to more than once a week
margins, predict(pr outcome(1)) at(attend=(1 6))
margins, predict(pr outcome(2)) at(attend=(1 6))
margins, predict(pr outcome(3)) at(attend=(1 6))



